@@ -33,7 +33,7 @@ class AKONADI_MIME_EXPORT MoveCommand : public CommandBase
     Q_OBJECT
 public:
     MoveCommand(const Akonadi::Collection &destFolder, const Akonadi::Item::List &msgList, QObject *parent = nullptr);
-    ~MoveCommand();
+    ~MoveCommand() override;
     void execute() override;
 
 private Q_SLOTS:
